@@ -9,7 +9,7 @@
  * in supporting documentation.  Silicon Graphics makes no
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied warranty.
- */
+ */ 
 
 
 #include <stdlib.h>
@@ -37,61 +37,43 @@ size_t mbrlen (const char* s, size_t n, mbstate_t *ps);
 
 #include <nl_types.h>
 
-void _Locale_init()
-{}
 
-void _Locale_final()
-{}
-
-typedef struct _Locale_ctype    {
+typedef struct _Locale_ctype    { 
   const struct locale_data* gcc_data;
   const int* __tolower;
   const int* __toupper;
   _Locale_mask_t* __class;
 } L_ctype_t;
 
-typedef struct _Locale_numeric  {
+typedef struct _Locale_numeric  { 
   const struct locale_data* gcc_data;
 } L_numeric_t;
 
-typedef struct _Locale_time     {
+typedef struct _Locale_time     { 
   const struct locale_data* gcc_data;
 } L_time_t;
 
-typedef struct _Locale_collate  {
+typedef struct _Locale_collate  { 
   const struct locale_data* gcc_data;
 } L_collate_t;
 
-typedef struct _Locale_monetary {
+typedef struct _Locale_monetary { 
   const struct locale_data* gcc_data;
 } L_monetary_t;
 
-typedef struct _Locale_messages {
+typedef struct _Locale_messages { 
   const struct locale_data* gcc_data;
 } L_messages_t;
 
-struct _Locale_name_hint* _Locale_get_ctype_hint(struct _Locale_ctype* ctype)
-{ return 0; }
-struct _Locale_name_hint* _Locale_get_numeric_hint(struct _Locale_numeric* numeric)
-{ return 0; }
-struct _Locale_name_hint* _Locale_get_time_hint(struct _Locale_time* time)
-{ return 0; }
-struct _Locale_name_hint* _Locale_get_collate_hint(struct _Locale_collate* collate)
-{ return 0; }
-struct _Locale_name_hint* _Locale_get_monetary_hint(struct _Locale_monetary* monetary)
-{ return 0; }
-struct _Locale_name_hint* _Locale_get_messages_hint(struct _Locale_messages* messages)
-{ return 0; }
-
-static char const*
+static char *
 _Locale_extract_name ( const char *cname, char *into, int category )
 {
   int i = 0;
   const char * end;
-
+  
   if ( cname[0] != '/' )
     return strcpy(into, cname); /* simple locale name */
-
+  
   for ( i = 0; i <= category; i ++ ) {
     while ( *cname != '\0' && *cname != '/' )
       cname++;
@@ -99,21 +81,21 @@ _Locale_extract_name ( const char *cname, char *into, int category )
       return into;
     cname++;
   }
-
+  
   if ( *cname == '\0' )
     return into;
-
+  
   end = cname;
   while ( *end != '\0' && *end != '/' )
     end++;
-
+  
   strncpy ( into, cname, end - cname );
   into [ end - cname ] = '\0';
-
+  
   return into;
 }
 
-char const* _Locale_name(const struct locale_data* gcc_data,
+char* _Locale_name(const struct locale_data* gcc_data, 
             char* buf)
 {
   if (!(gcc_data && gcc_data->name)) return 0;
@@ -157,16 +139,16 @@ _Category_create(const char * name, int category)
   size_t locale_path_len = 0;
 
   locpath_var = __secure_getenv("LOCPATH");
-
+  
   if (locpath_var != NULL && locpath_var[0] != '\0')
     if (argz_create_sep (locpath_var, ':',
        &locale_path, &locale_path_len) != 0)
       return NULL;
-
+  
   if (argz_add_sep (&locale_path, &locale_path_len, __LOCALE_PATH, ':') != 0)
     return NULL;
 
-  return _Find_locale(locale_path, locale_path_len,
+  return _Find_locale(locale_path, locale_path_len, 
           category, (char**)&name);
 }
 
@@ -183,13 +165,13 @@ static const char* get_default_locale(char* buf) {
     return buf;
   }
 }
-
+    
 const char* _Locale_ctype_default(char* buf) {
   char fullname[_Locale_MAX_COMPOSITE_NAME];
   if (get_default_locale(fullname) == NULL)
     return NULL;
   else
-    return _Locale_extract_ctype_name(fullname, buf, 0);
+    return _Locale_extract_ctype_name(fullname, buf);
 }
 
 const char* _Locale_numeric_default(char* buf) {
@@ -197,7 +179,7 @@ const char* _Locale_numeric_default(char* buf) {
   if (get_default_locale(fullname) == NULL)
     return NULL;
   else
-    return _Locale_extract_numeric_name(fullname, buf, 0);
+    return _Locale_extract_numeric_name(fullname, buf);
 }
 
 const char* _Locale_time_default(char* buf) {
@@ -205,7 +187,7 @@ const char* _Locale_time_default(char* buf) {
   if (get_default_locale(fullname) == NULL)
     return NULL;
   else
-    return _Locale_extract_time_name(fullname, buf, 0);
+    return _Locale_extract_time_name(fullname, buf);
 }
 
 const char* _Locale_collate_default(char* buf)  {
@@ -213,7 +195,7 @@ const char* _Locale_collate_default(char* buf)  {
   if (get_default_locale(fullname) == NULL)
     return NULL;
   else
-    return _Locale_extract_collate_name(fullname, buf, 0);
+    return _Locale_extract_collate_name(fullname, buf);
 }
 
 const char* _Locale_monetary_default(char* buf) {
@@ -221,7 +203,7 @@ const char* _Locale_monetary_default(char* buf) {
   if (get_default_locale(fullname) == NULL)
     return NULL;
   else
-    return _Locale_extract_monetary_name(fullname, buf, 0);
+    return _Locale_extract_monetary_name(fullname, buf);
 }
 
 const char* _Locale_messages_default(char* buf) {
@@ -229,54 +211,54 @@ const char* _Locale_messages_default(char* buf) {
   if (get_default_locale(fullname) == NULL)
     return NULL;
   else
-    return _Locale_extract_messages_name(fullname, buf, 0);
+    return _Locale_extract_messages_name(fullname, buf);
 }
 
 
 /****** Numeric Category ******/
 
 void*
-_Locale_numeric_create(const char * name, struct _Locale_name_hint* hint) {
+_Locale_numeric_create(const char * name) {
   L_numeric_t*  lnum = (L_numeric_t*)malloc(sizeof(L_numeric_t));
   lnum->gcc_data = _Category_create(name, LC_NUMERIC);
-  return (void*)lnum;
+  return (void*)lnum; 
 }
 
 
-char const* _Locale_numeric_name(const void* lnum,
+char* _Locale_numeric_name(const void* lnum, 
               char* buf) {
   return _Locale_name(((struct _Locale_ctype*)lnum)->gcc_data, buf);
 }
-void _Locale_numeric_destroy(void* lnum)
+void _Locale_numeric_destroy(void* lnum)   
 {
   _Remove_locale(LC_NUMERIC, (struct locale_data *)((struct _Locale_ctype*)lnum)->gcc_data);
   free(lnum);
 }
-char const* _Locale_extract_numeric_name(const char* cname, char* buf, struct _Locale_name_hint* hint)
+char* _Locale_extract_numeric_name(const char* cname, char* buf) 
 {
   return _Locale_extract_name(cname, buf, LC_NUMERIC);
 }
 char _Locale_decimal_point(struct _Locale_numeric* lnum)
-{
-  return lnum->gcc_data->values[_NL_ITEM_INDEX(DECIMAL_POINT)].string[0];
+{ 
+  return lnum->gcc_data->values[_NL_ITEM_INDEX(DECIMAL_POINT)].string[0]; 
 }
 char _Locale_thousands_sep(struct _Locale_numeric* lnum)
-{
-  return lnum->gcc_data->values[_NL_ITEM_INDEX(THOUSANDS_SEP)].string[0];
+{ 
+  return lnum->gcc_data->values[_NL_ITEM_INDEX(THOUSANDS_SEP)].string[0]; 
 }
-const char* _Locale_grouping(struct _Locale_numeric * lnum)
+const char* _Locale_grouping(struct _Locale_numeric * lnum) 
 {
-  return lnum->gcc_data->values[_NL_ITEM_INDEX(GROUPING)].string;
+  return lnum->gcc_data->values[_NL_ITEM_INDEX(GROUPING)].string; 
 }
 
 /* JGS: gcc/linux does not provide true/false names in their
- * locale data files
+ * locale data files 
 */
 
 static const char* __true_name = "true";
 static const char* __false_name = "false";
 
-const char * _Locale_true(struct _Locale_numeric *l)
+const char * _Locale_true(struct _Locale_numeric *l)  
 { return __true_name; }
 const char * _Locale_false(struct _Locale_numeric *l)
 { return __false_name; }
@@ -284,13 +266,13 @@ const char * _Locale_false(struct _Locale_numeric *l)
 
 /****** Monetary Category ******/
 
-void* _Locale_monetary_create(const char* name, struct _Locale_name_hint* hint) {
+void* _Locale_monetary_create(const char* name) {
   L_monetary_t* lmon = (L_monetary_t*)malloc(sizeof(L_monetary_t));
   lmon->gcc_data = _Category_create(name, LC_MONETARY);
   return lmon;
 }
 
-char const* _Locale_monetary_name(const void* lmon,
+char* _Locale_monetary_name(const void* lmon,
           char* buf) {
   return _Locale_name(((struct _Locale_monetary*)lmon)->gcc_data, buf);
 }
@@ -300,69 +282,69 @@ void _Locale_monetary_destroy(void*lmon) {
   free(lmon);
 }
 
-char const* _Locale_extract_monetary_name(const char* cname, char* buf, struct _Locale_name_hint* hint) {
+char* _Locale_extract_monetary_name(const char* cname, char* buf) {
   return _Locale_extract_name(cname, buf, LC_MONETARY);
 }
 
 const char* _Locale_int_curr_symbol(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(INT_CURR_SYMBOL)].string;
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(INT_CURR_SYMBOL)].string; 
 }
 const char* _Locale_currency_symbol(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(CURRENCY_SYMBOL)].string;
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(CURRENCY_SYMBOL)].string; 
 }
 char        _Locale_mon_decimal_point(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(MON_DECIMAL_POINT)].string[0];
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(MON_DECIMAL_POINT)].string[0]; 
 }
 char        _Locale_mon_thousands_sep(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(MON_THOUSANDS_SEP)].string[0];
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(MON_THOUSANDS_SEP)].string[0]; 
 }
 const char* _Locale_mon_grouping(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(MON_GROUPING)].string;
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(MON_GROUPING)].string; 
 }
 const char* _Locale_positive_sign(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(POSITIVE_SIGN)].string;
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(POSITIVE_SIGN)].string; 
 }
 const char* _Locale_negative_sign(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(NEGATIVE_SIGN)].string;
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(NEGATIVE_SIGN)].string; 
 }
 char        _Locale_int_frac_digits(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(INT_FRAC_DIGITS)].string[0];
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(INT_FRAC_DIGITS)].string[0]; 
 }
 char        _Locale_frac_digits(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(FRAC_DIGITS)].string[0];
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(FRAC_DIGITS)].string[0]; 
 }
 int         _Locale_p_cs_precedes(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(P_CS_PRECEDES)].word;
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(P_CS_PRECEDES)].word; 
 }
 int         _Locale_p_sep_by_space(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(P_SEP_BY_SPACE)].word;
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(P_SEP_BY_SPACE)].word; 
 }
 int         _Locale_p_sign_posn(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(P_SIGN_POSN)].word;
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(P_SIGN_POSN)].word; 
 }
 int         _Locale_n_cs_precedes(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(N_CS_PRECEDES)].word;
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(N_CS_PRECEDES)].word; 
 }
 int          _Locale_n_sep_by_space(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(N_SEP_BY_SPACE)].word;
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(N_SEP_BY_SPACE)].word; 
 }
 int          _Locale_n_sign_posn(struct _Locale_monetary* lmon) {
-  return lmon->gcc_data->values[_NL_ITEM_INDEX(N_SIGN_POSN)].word;
+  return lmon->gcc_data->values[_NL_ITEM_INDEX(N_SIGN_POSN)].word; 
 }
 
 /****** Time Category ******/
 
-void* _Locale_time_create(const char * name, struct _Locale_name_hint* hint) {
+void* _Locale_time_create(const char * name) {
   L_time_t*  ltime = (L_time_t*)malloc(sizeof(L_time_t));
   ltime->gcc_data = _Category_create(name, LC_TIME);
-  return ltime;
+  return ltime; 
 }
 
-char const* _Locale_time_name(const void* ltime,
+char* _Locale_time_name(const void* ltime, 
       char* buf) {
   return _Locale_name(((struct _Locale_time*)ltime)->gcc_data, buf);
 }
-char const* _Locale_extract_time_name(const char* cname, char* buf, struct _Locale_name_hint* hint) {
+char* _Locale_extract_time_name(const char* cname, char* buf) {
   return _Locale_extract_name(cname, buf, LC_TIME);
 }
 void _Locale_time_destroy(void* ltime) {
@@ -371,58 +353,58 @@ void _Locale_time_destroy(void* ltime) {
 }
 const char * _Locale_full_monthname(struct _Locale_time *ltime, int month) {
   const char **names = (const char **)&(ltime->gcc_data->values[_NL_ITEM_INDEX(MON_1)]);
-  return names[month];
+  return names[month]; 
 }
 const char * _Locale_abbrev_monthname(struct _Locale_time *ltime, int month) {
   const char **names = (const char **)&(ltime->gcc_data->values[_NL_ITEM_INDEX(ABMON_1)]);
-  return names[month];
+  return names[month]; 
 }
 const char * _Locale_full_dayofweek(struct _Locale_time *ltime, int day) {
   const char **names = (const char **)&(ltime->gcc_data->values[_NL_ITEM_INDEX(DAY_1)]);
-  return names[day];
+  return names[day]; 
 }
 const char * _Locale_abbrev_dayofweek(struct _Locale_time *ltime, int day) {
   const char **names = (const char **)&(ltime->gcc_data->values[_NL_ITEM_INDEX(ABDAY_1)]);
-  return names[day];
+  return names[day]; 
 }
 const char* _Locale_d_t_fmt(struct _Locale_time* ltime) {
-  return ltime->gcc_data->values[_NL_ITEM_INDEX(D_T_FMT)].string;
+  return ltime->gcc_data->values[_NL_ITEM_INDEX(D_T_FMT)].string; 
 }
 const char* _Locale_long_d_t_fmt(struct _Locale_time* ltime) {
-  return ltime->gcc_data->values[_NL_ITEM_INDEX(D_T_FMT)].string;
+  return ltime->gcc_data->values[_NL_ITEM_INDEX(D_T_FMT)].string; 
 }
-const char* _Locale_d_fmt(struct _Locale_time* ltime)
+const char* _Locale_d_fmt(struct _Locale_time* ltime) 
 {
-  return ltime->gcc_data->values[_NL_ITEM_INDEX(D_FMT)].string;
+  return ltime->gcc_data->values[_NL_ITEM_INDEX(D_FMT)].string; 
 }
 const char* _Locale_long_d_fmt(struct _Locale_time* ltime)
 {
   return ltime->gcc_data->values[_NL_ITEM_INDEX(D_FMT)].string;
 }
 const char* _Locale_t_fmt(struct _Locale_time* ltime) {
-  return ltime->gcc_data->values[_NL_ITEM_INDEX(T_FMT)].string;
+  return ltime->gcc_data->values[_NL_ITEM_INDEX(T_FMT)].string; 
 }
 const char* _Locale_am_str(struct _Locale_time* ltime) {
-  return ltime->gcc_data->values[_NL_ITEM_INDEX(AM_STR)].string;
+  return ltime->gcc_data->values[_NL_ITEM_INDEX(AM_STR)].string; 
 }
 const char* _Locale_pm_str(struct _Locale_time* ltime) {
-  return ltime->gcc_data->values[_NL_ITEM_INDEX(PM_STR)].string;
+  return ltime->gcc_data->values[_NL_ITEM_INDEX(PM_STR)].string; 
 }
 const char* _Locale_t_fmt_ampm(struct _Locale_time* ltime)
 {
-  return ltime->gcc_data->values[_NL_ITEM_INDEX(T_FMT_AMPM)].string;
+  return ltime->gcc_data->values[_NL_ITEM_INDEX(T_FMT_AMPM)].string; 
 }
 
 
 /****** Messages Category ******/
 
-void* _Locale_messages_create(const char * name, struct _Locale_name_hint* hint) {
+void* _Locale_messages_create(const char * name) {
   L_messages_t*  lmsg = (L_messages_t*)malloc(sizeof(L_messages_t));
   lmsg->gcc_data = _Category_create(name, LC_MESSAGES);
-  return lmsg;
+  return lmsg; 
 }
 
-char const* _Locale_messages_name(const void* lmsg, char* buf) {
+char* _Locale_messages_name(const void* lmsg, char* buf) {
   return _Locale_name(((struct _Locale_messages*)lmsg)->gcc_data, buf);
 }
 
@@ -431,7 +413,7 @@ void _Locale_messages_destroy(void* lmsg) {
   free(lmsg);
 }
 
-char const* _Locale_extract_messages_name(const char* cname, char* buf, struct _Locale_name_hint* hint) {
+char* _Locale_extract_messages_name(const char* cname, char* buf) { 
   return _Locale_extract_name(cname, buf, LC_MESSAGES);
 }
 
@@ -466,7 +448,7 @@ const char* _Locale_catgets(struct _Locale_messages*l, int catalog,
   gcc uses a different set of masks for wide characters than for
   normal characters. However, the C++ standard requires there
   to be only one set of masks for both. Therefore we must
-  translate the mask values from the wide characters to the
+  translate the mask values from the wide characters to the 
   mask values for the normal characters.  -JGS
  */
 static _Locale_mask_t _Map_wchar_mask_to_char_mask(wctype_t m) {
@@ -484,7 +466,7 @@ static _Locale_mask_t _Map_wchar_mask_to_char_mask(wctype_t m) {
 }
 
 
-void* _Locale_ctype_create(const char * name, struct _Locale_name_hint* hint) {
+void* _Locale_ctype_create(const char * name) {
   const union locale_data_value *ctypes;
   L_ctype_t* lctype;
 
@@ -516,7 +498,7 @@ void* _Locale_ctype_create(const char * name, struct _Locale_name_hint* hint) {
 #endif /* _STLP_GLIBC_LOCALE_2 */
   return lctype;
 }
-char const* _Locale_ctype_name(const void* lctype,
+char* _Locale_ctype_name(const void* lctype,
        char* buf) {
   return _Locale_name(((struct _Locale_ctype*)lctype)->gcc_data, buf);
 }
@@ -524,16 +506,16 @@ void _Locale_ctype_destroy(void* lctype) {
   _Remove_locale(LC_CTYPE, (struct locale_data *)((struct _Locale_ctype*)lctype)->gcc_data);
   free(lctype);
 }
-char const* _Locale_extract_ctype_name(const char* cname, char* buf, struct _Locale_name_hint* hint) {
+char* _Locale_extract_ctype_name(const char* cname, char* buf) {
   return _Locale_extract_name(cname, buf, LC_CTYPE);
 }
 const _Locale_mask_t* _Locale_ctype_table(struct _Locale_ctype* lctype) {
-  return lctype->__class;
+  return lctype->__class; 
 }
-int _Locale_toupper(struct _Locale_ctype* lctype, int c) {
+int _Locale_toupper(struct _Locale_ctype* lctype, int c) { 
   return lctype->__toupper[c];
 }
-int _Locale_tolower(struct _Locale_ctype* lctype, int c) {
+int _Locale_tolower(struct _Locale_ctype* lctype, int c) { 
   return lctype->__tolower[c];
 }
 
@@ -613,17 +595,17 @@ wint_t _Locale_wchar_toupper(struct _Locale_ctype* locale, wint_t wc) {
 }
 
 
-int _Locale_mb_cur_max (struct _Locale_ctype *lctype) {
-  return lctype->gcc_data->values[_NL_ITEM_INDEX(_NL_CTYPE_MB_CUR_MAX)].word;
+int _Locale_mb_cur_max (struct _Locale_ctype *lctype) { 
+  return lctype->gcc_data->values[_NL_ITEM_INDEX(_NL_CTYPE_MB_CUR_MAX)].word; 
 }
 
-int _Locale_mb_cur_min (struct _Locale_ctype *l) {
+int _Locale_mb_cur_min (struct _Locale_ctype *l) { 
   return 1;  /* JGS just a guess */
 }
 
 int _Locale_is_stateless (struct _Locale_ctype *l) { return 1; }
 
-wint_t _Locale_btowc(struct _Locale_ctype *l, int c) {
+wint_t _Locale_btowc(struct _Locale_ctype *l, int c) { 
   return btowc(c);
 }
 
@@ -636,7 +618,7 @@ wint_t _Locale_btowc(struct _Locale_ctype *l, int c) {
   -JGS
  */
 
-int _Locale_wctob(struct _Locale_ctype *l, wint_t c) {
+int _Locale_wctob(struct _Locale_ctype *l, wint_t c) { 
   return wctob(c);
 }
 
@@ -685,13 +667,13 @@ size_t _Locale_unshift(struct _Locale_ctype *l,
 
 /****** Collate Category ******/
 
-void* _Locale_collate_create(const char * name, struct _Locale_name_hint* hint) {
+void* _Locale_collate_create(const char * name) {
   L_collate_t*  lcollate = (L_collate_t*)malloc(sizeof(L_collate_t));
   lcollate->gcc_data = _Category_create(name, LC_COLLATE);
-  return lcollate;
+  return lcollate; 
 }
 
-char const* _Locale_collate_name(const void* lcollate, char* buf) {
+char* _Locale_collate_name(const void* lcollate, char* buf) {
   return _Locale_name(((struct _Locale_collate*)lcollate)->gcc_data, buf);
 }
 
@@ -700,12 +682,12 @@ void _Locale_collate_destroy(void* lcollate) {
   free(lcollate);
 }
 
-char const* _Locale_extract_collate_name(const char* cname, char* buf, struct _Locale_name_hint* hint) {
+char* _Locale_extract_collate_name(const char* cname, char* buf) {
   return _Locale_extract_name(cname, buf, LC_COLLATE);
 }
 
 /* copied from the IRIX version -JGS */
-char const* _Locale_compose_name(char* buf,
+char* _Locale_compose_name(char* buf,
          const char* ctype, const char* numeric,
          const char* time, const char* collate,
          const char* monetary, const char* messages,
@@ -778,54 +760,28 @@ int _Locale_strwcmp(struct _Locale_collate*l,
   } else
     return ret;
 }
-size_t _Locale_strxfrm(struct _Locale_collate *lcollate,
-                       char *dest, size_t dest_n,
-                       const char *src, size_t src_n )
+
+
+
+size_t _Locale_strxfrm(struct _Locale_collate* lcollate,
+           char* dest, size_t destN, const char* src, size_t srcN)
 {
-  if (src_n == 0)
-  {
-    if (dest != NULL) dest[0] = 0;
-    return 0;
-  }
-  const char *real_src;
-  char *buf = NULL;
-  if (src[src_n] != 0) {
-    buf = malloc(src_n + 1);
-    strncpy(buf, src, src_n);
-    buf[src_n] = 0;
-    real_src = buf;
-  }
-  else
-    real_src = src;
-  size_t result = strxfrm(dest, real_src, dest_n);
-  if (buf != NULL) free(buf);
-  return result;
+  size_t n;
+  n = strxfrm(dest, src, destN);
+  if (n > destN)
+    return (size_t)-1;
+  dest[n] = 0;
+  return n;
 }
 
-# ifndef _STLP_NO_WCHAR_T
-
-size_t _Locale_strwxfrm(struct _Locale_collate *lcollate,
-                        wchar_t *dest, size_t dest_n,
-                        const wchar_t *src, size_t src_n)
+size_t _Locale_strwxfrm(struct _Locale_collate* lcollate,
+      wchar_t* dest, size_t destN, 
+      const wchar_t* src, size_t srcN)
 {
-  if (src_n == 0)
-  {
-    if (dest != NULL) dest[0] = 0;
-    return 0;
-  }
-  const wchar_t *real_src;
-  wchar_t *buf = NULL;
-  if (src[src_n] != 0) {
-    buf = malloc((src_n + 1) * sizeof(wchar_t));
-    wcsncpy(buf, src, src_n);
-    buf[src_n] = 0;
-    real_src = buf;
-  }
-  else
-    real_src = src;
-  size_t result = wcsxfrm(dest, real_src, dest_n, (__c_locale)__loc);
-  if (buf != NULL) free(buf);
-  return result;
+  size_t n;
+  n = wcsxfrm(dest, src, destN);
+  if (n > destN)
+    return (size_t)-1;
+  dest[n] = 0;
+  return n;
 }
-
-#endif
