@@ -2,24 +2,24 @@
  * Copyright (c) 1999
  * Silicon Graphics Computer Systems, Inc.
  *
- * Copyright (c) 1999
+ * Copyright (c) 1999 
  * Boris Fomitchev
  *
  * This material is provided "as is", with absolutely no warranty expressed
  * or implied. Any use is at your own risk.
  *
- * Permission to use or copy this software for any purpose is hereby granted
+ * Permission to use or copy this software for any purpose is hereby granted 
  * without fee, provided the above notices are retained on all copies.
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
  *
- */
-#ifndef _STLP_INTERNAL_ISTREAM
-#define _STLP_INTERNAL_ISTREAM
+ */ 
+#ifndef _STLP_INTERNAL_ISTREAM_H
+#define _STLP_INTERNAL_ISTREAM_H
 
 // this block is included by _ostream.h, we include it here to lower #include level
-#if defined (_STLP_HAS_WCHAR_T) && !defined (_STLP_INTERNAL_CWCHAR)
+#if defined (_STLP_HAS_WCHAR_T) && !defined (_STLP_CWCHAR_H)
 #  include <stl/_cwchar.h>
 #endif
 
@@ -57,7 +57,7 @@ bool _M_init_noskip(basic_istream<_CharT, _Traits>& __istr);
 
 // The second template parameter, _Traits, defaults to char_traits<_CharT>.
 // The default is declared in header <iosfwd>, and it isn't declared here
-// because C++ language rules do not allow it to be declared twice.
+// because C++ language rules do not allow it to be declared twice. 
 
 template <class _CharT, class _Traits>
 class basic_istream : virtual public basic_ios<_CharT, _Traits> {
@@ -68,7 +68,7 @@ class basic_istream : virtual public basic_ios<_CharT, _Traits> {
   basic_istream(_Self const&);
   _Self& operator = (_Self const&);
 #endif
-
+  
 public:
                          // Types
   typedef _CharT                     char_type;
@@ -107,7 +107,7 @@ public:                         // Formatted input of numbers.
 #ifdef _STLP_LONG_LONG
   _Self& operator>> (_STLP_LONG_LONG& __val);
   _Self& operator>> (unsigned _STLP_LONG_LONG& __val);
-#endif
+#endif 
   _Self& operator>> (float& __val);
   _Self& operator>> (double& __val);
 # ifndef _STLP_NO_LONG_DOUBLE
@@ -190,35 +190,35 @@ class _Isentry {
   class sentry {
     typedef sentry _Self;
 #endif
-
+    
   private:
     const bool _M_ok;
     //    basic_streambuf<_CharT, _Traits>* _M_buf;
-
+        
   public:
     typedef _Traits traits_type;
-
+    
     explicit sentry(basic_istream<_CharT, _Traits>& __istr,
-                    bool __noskipws = false) :
+                    bool __noskipws = false) : 
       _M_ok((__noskipws || !(__istr.flags() & ios_base::skipws)) ? _M_init_noskip(__istr) : _M_init_skip(__istr) )
       /* , _M_buf(__istr.rdbuf()) */
       {}
-
-    // Calling this constructor is the same as calling the previous one with
+    
+    // Calling this constructor is the same as calling the previous one with 
     // __noskipws = true, except that it doesn't require a runtime test.
     sentry(basic_istream<_CharT, _Traits>& __istr, _No_Skip_WS) : /* _M_buf(__istr.rdbuf()), */
       _M_ok(_M_init_noskip(__istr)) {}
-
+    
     ~sentry() {}
-
+    
     operator bool() const { return _M_ok; }
-
+    
   private:                        // Disable assignment and copy constructor.
     //Implementation is here only to avoid warning with some compilers.
     sentry(const _Self&) : _M_ok(false) {}
     _Self& operator=(const _Self&) { return *this; }
   };
-
+  
 # if defined (_STLP_USE_TEMPLATE_EXPORT)
 #  undef sentry
 # else
@@ -237,42 +237,42 @@ _STLP_EXPORT_TEMPLATE_CLASS basic_istream<wchar_t, char_traits<wchar_t> >;
 
 // Non-member character and string extractor functions.
 template <class _CharT, class _Traits>
-inline basic_istream<_CharT, _Traits>& _STLP_CALL
+inline basic_istream<_CharT, _Traits>& _STLP_CALL  
 operator>>(basic_istream<_CharT, _Traits>& __in_str, _CharT& __c) {
   __in_str._M_formatted_get(__c);
   return __in_str;
 }
 
 template <class _Traits>
-inline basic_istream<char, _Traits>& _STLP_CALL
+inline basic_istream<char, _Traits>& _STLP_CALL  
 operator>>(basic_istream<char, _Traits>& __in_str, unsigned char& __c) {
   __in_str._M_formatted_get(__REINTERPRET_CAST(char&,__c));
   return __in_str;
 }
 
 template <class _Traits>
-inline basic_istream<char, _Traits>& _STLP_CALL
+inline basic_istream<char, _Traits>& _STLP_CALL 
 operator>>(basic_istream<char, _Traits>& __in_str, signed char& __c) {
   __in_str._M_formatted_get(__REINTERPRET_CAST(char&,__c));
   return __in_str;
 }
 
 template <class _CharT, class _Traits>
-inline basic_istream<_CharT, _Traits>& _STLP_CALL
+inline basic_istream<_CharT, _Traits>& _STLP_CALL 
 operator>>(basic_istream<_CharT, _Traits>& __in_str, _CharT* __s) {
   __in_str._M_formatted_get(__s);
   return __in_str;
 }
 
 template <class _Traits>
-inline basic_istream<char, _Traits>& _STLP_CALL
+inline basic_istream<char, _Traits>& _STLP_CALL 
 operator>>(basic_istream<char, _Traits>& __in_str, unsigned char* __s) {
   __in_str._M_formatted_get(__REINTERPRET_CAST(char*,__s));
   return __in_str;
 }
 
 template <class _Traits>
-inline basic_istream<char, _Traits>& _STLP_CALL
+inline basic_istream<char, _Traits>& _STLP_CALL 
 operator>>(basic_istream<char, _Traits>& __in_str, signed char* __s) {
   __in_str._M_formatted_get(__REINTERPRET_CAST(char*,__s));
   return __in_str;
@@ -283,12 +283,10 @@ operator>>(basic_istream<char, _Traits>& __in_str, signed char* __s) {
 template <class _CharT, class _Traits>
 basic_istream<_CharT, _Traits>& _STLP_CALL
 ws(basic_istream<_CharT, _Traits>& __istr) {
-  if (!__istr.eof()) {
-    typedef typename basic_istream<_CharT, _Traits>::sentry      _Sentry;
-    _Sentry __sentry(__istr, _No_Skip_WS()); // Don't skip whitespace.
-    if (__sentry)
-      __istr._M_skip_whitespace(false);
-  }
+  typedef typename basic_istream<_CharT, _Traits>::sentry      _Sentry;
+  _Sentry __sentry(__istr, _No_Skip_WS()); // Don't skip whitespace.
+  if (__sentry)
+    __istr._M_skip_whitespace(false);
   return __istr;
 }
 
@@ -298,10 +296,10 @@ inline bool _M_init_skip(basic_istream<_CharT, _Traits>& __istr) {
   if (__istr.good()) {
     if (__istr.tie())
       __istr.tie()->flush();
-
+    
     __istr._M_skip_whitespace(true);
   }
-
+  
   if (!__istr.good()) {
     __istr.setstate(ios_base::failbit);
     return false;
@@ -314,7 +312,7 @@ inline bool _M_init_noskip(basic_istream<_CharT, _Traits>& __istr) {
   if (__istr.good()) {
     if (__istr.tie())
       __istr.tie()->flush();
-
+    
     if (!__istr.rdbuf())
       __istr.setstate(ios_base::badbit);
   }
@@ -326,7 +324,7 @@ inline bool _M_init_noskip(basic_istream<_CharT, _Traits>& __istr) {
 //----------------------------------------------------------------------
 // Class iostream.
 template <class _CharT, class _Traits>
-class basic_iostream
+class basic_iostream 
   : public basic_istream<_CharT, _Traits>,
     public basic_ostream<_CharT, _Traits>
 {
@@ -346,7 +344,7 @@ _STLP_EXPORT_TEMPLATE_CLASS basic_iostream<wchar_t, char_traits<wchar_t> >;
 # endif /* _STLP_USE_TEMPLATE_EXPORT */
 
 template <class _CharT, class _Traits>
-basic_streambuf<_CharT, _Traits>* _STLP_CALL _M_get_istreambuf(basic_istream<_CharT, _Traits>& __istr)
+basic_streambuf<_CharT, _Traits>* _STLP_CALL _M_get_istreambuf(basic_istream<_CharT, _Traits>& __istr) 
 { return __istr.rdbuf(); }
 
 _STLP_END_NAMESPACE
@@ -355,7 +353,7 @@ _STLP_END_NAMESPACE
 #  include <stl/_istream.c>
 #endif
 
-#endif /* _STLP_INTERNAL_ISTREAM */
+#endif /* _STLP_INTERNAL_ISTREAM_H */
 
 // Local Variables:
 // mode:C++
